@@ -1,7 +1,7 @@
 /* CatalystX::CRUD::YUI custom JavaScript 
 
 # sync with .pm files
-my $VERSION = '0.016';   
+my $VERSION = '0.017';   
 
 */
 YAHOO.namespace('crud');
@@ -292,6 +292,18 @@ YAHOO.crud.toggle_class_hidden = function(id) {
     YAHOO.crud.toggle_class(id, "hidden");
 }
 
+YAHOO.crud.toggle_action_buttons = function(id) {
+    Logger('toggle action buttons ' + id);
+    var Dom = YAHOO.util.Dom;
+    var el = Dom.get('crud-buttons');
+    if (!id || id == 'main') {
+        Dom.removeClass(el,'hidden');
+    }
+    else {
+        Dom.addClass(el,'hidden');
+    }
+}
+
 YAHOO.crud.init_tabview_history = function() {
     var currentState;
     currentState = YAHOO.util.History.getCurrentState('tabview');
@@ -310,8 +322,12 @@ YAHOO.crud.handle_crud_link_click = function(e) {
             var id;
             if (ahref.match(/#/)) {
                 id = ahref.match(/#(.+)/)[1];
+                // hide the parent record buttons to reduce confusion
+                YAHOO.crud.toggle_action_buttons(id);
             }
             else {
+                // show the parent record buttons
+                YAHOO.crud.toggle_action_buttons();
                 return true;
             }
             // manage history
@@ -357,6 +373,7 @@ YAHOO.crud.set_active_tab = function(id) {
     YAHOO.crud.toggle_class(id, "hidden");
     YAHOO.crud.toggle_class(YAHOO.crud.ACTIVE_TAB + '-link', "selected");
     YAHOO.crud.toggle_class(id + '-link', "selected");
+    YAHOO.crud.toggle_action_buttons(id);
     
     YAHOO.crud.ACTIVE_TAB = id;
     YAHOO.crud.load_livegrid_by_id(id);
@@ -688,6 +705,31 @@ YAHOO.crud.new_livegrid = function(index) {
             sortInfo   : {field: opts.sort_by, direction: opts.sort_dir},
             url        : opts.url
         });
+        
+        /*  support sorting on foreign m2m fields 
+            by adding the table prefix where necessary
+        */
+        this.store.on('beforeload', 
+            function(myStore) { 
+                var sortInfo = myStore.sortInfo;
+                //Logger(sortInfo.field, sortInfo.direction);
+                for(var i=0; i<opts.column_defs.length; i++) {
+                    var c = opts.column_defs[i];
+                    if (c.dataIndex === sortInfo.field
+                        && c.sortPrefix
+                        && c.sortPrefix.length
+                    ) 
+                    {
+                        //Logger("match: " + c.dataIndex);
+                        sortInfo.field = c.sortPrefix + '.' + sortInfo.field;
+                        break;
+                    }
+                }
+                //Logger(sortInfo.field, sortInfo.direction);
+                //Logger(opts.column_defs);
+                //alert("beforeload!");
+            }
+        );
 
         this.selModel = 
             new Ext.ux.grid.livegrid.RowSelectionModel({singleSelect: true});
@@ -1283,10 +1325,15 @@ YAHOO.crud.wysiwygify = function( textareaId, textareaTitle ) {
     // make sure the 'save' button writes changes to textarea
     YAHOO.crud.onFormSubmit.push(
      function() {
-        //alert("textarea: " + myEditor.get('textarea').value );
+        var editorText = myEditor.get('textarea').value;
+        var textareaText = Dom.get(textareaId).value;
+        //alert(textareaId + " textarea: " + editorText);
+        if (editorText != textareaText) {
+            alert("editor text mismatch: " + editorText + ' <> ' + textareaText);
+        }
         myEditor.saveHTML();
-        if (myEditor.get('textarea').value.length) {
-            myEditor.get('textarea').value = myEditor.get('textarea').value.replace(/<br>/gi, '\n');
+        if (editorText.length) {
+            myEditor.get('textarea').value = editorText.replace(/<br>/gi, '\n');
         }
         //alert("textarea: " + myEditor.get('textarea').value );
         return true;
